@@ -37,10 +37,9 @@ T = TypeVar("T")
 
 
 def is_retryable_exception(e: Exception) -> bool:
-    if isinstance(e, ClientError):
-        if e.response["Error"]["Code"] in RetryableErrors:
-            log.debug("AWS API request limit exceeded or throttling, retrying with exponential backoff")
-            return True
+    if isinstance(e, ClientError) and e.response["Error"]["Code"] in RetryableErrors:
+        log.debug("AWS API request limit exceeded or throttling, retrying with exponential backoff")
+        return True
     return False
 
 
@@ -138,9 +137,10 @@ class AwsClient:
             raise AttributeError(f"Unsupported type: {type(node)}")
 
     def service_model(self, aws_service: str) -> ServiceModel:
-        session = self.config.sessions().session(self.account_id, self.role, self.profile)
-        client = session.client(aws_service, region_name=self.region)
-        return client.meta.service_model
+        client = self.config.sessions().client(self.account_id, self.role, self.profile, aws_service, self.region)
+        model = client.meta.service_model
+        client.close()
+        return model
 
     def with_resource(self, aws_service: str, fn: Callable[[Any], T]) -> Optional[T]:
         """
@@ -151,8 +151,7 @@ class AwsClient:
         :param fn: loan pattern: the function is handed the resource and the result is returned.
         :return: the result of the function.
         """
-        session = self.config.sessions().session(self.account_id, self.role, self.profile)
-        resource = session.resource(aws_service, region_name=self.region)
+        resource = self.config.sessions().resource(self.account_id, self.role, self.profile, aws_service, self.region)
         try:
             return fn(resource)
         except ClientError as e:
@@ -175,38 +174,41 @@ class AwsClient:
         py_action = action.replace("-", "_")
         # adaptive mode allows automated client-side throttling
         config = Config(retries={"max_attempts": max_attempts, "mode": "adaptive"})
-        session = self.config.sessions().session(self.account_id, self.role, self.profile)
-        client = session.client(aws_service, region_name=self.region, config=config)
-        if client.can_paginate(py_action):
-            paginator = client.get_paginator(py_action)
-            result: List[Json] = []
-            for page in paginator.paginate(**kwargs):
-                log.debug2(f"[Aws] Get next page for service={aws_service} action={action}{arg_info}")  # type: ignore
-                next_page: Json = self.__to_json(page)  # type: ignore
-                if result_name is None:
-                    # the whole object is appended
-                    result.append(next_page)
-                else:
-                    child = value_in_path(next_page, result_name)
-                    if isinstance(child, list):
-                        result.extend(child)
-                    elif child is not None:
-                        result.append(child)
-            log.debug(f"[Aws] called service={aws_service} action={action}{arg_info}: {len(result)} results.")
-            return result
-        else:
-            result = getattr(client, py_action)(**kwargs)
-            single: Json = self.__to_json(result)  # type: ignore
-            log.debug(f"[Aws] called service={aws_service} action={action}{arg_info}: single result")
-            return value_in_path(single, result_name) if result_name else single
+        client = self.config.sessions().client(
+            self.account_id, self.role, self.profile, aws_service, self.region, config
+        )
+        try:
+            if client.can_paginate(py_action):
+                paginator = client.get_paginator(py_action)
+                result: List[Json] = []
+                for page in paginator.paginate(**kwargs):
+                    log.debug2(f"[Aws] Next page for service={aws_service} action={action}{arg_info}")  # type: ignore
+                    next_page: Json = self.__to_json(page)  # type: ignore
+                    if result_name is None:
+                        # the whole object is appended
+                        result.append(next_page)
+                    else:
+                        child = value_in_path(next_page, result_name)
+                        if isinstance(child, list):
+                            result.extend(child)
+                        elif child is not None:
+                            result.append(child)
+                log.debug(f"[Aws] called service={aws_service} action={action}{arg_info}: {len(result)} results.")
+                return result
+            else:
+                result = getattr(client, py_action)(**kwargs)
+                single: Json = self.__to_json(result)  # type: ignore
+                log.debug(f"[Aws] called service={aws_service} action={action}{arg_info}: single result")
+                return value_in_path(single, result_name) if result_name else single
+        finally:
+            client.close()
 
     @retry(  # type: ignore
-        stop_max_attempt_number=10,
-        wait_exponential_multiplier=3000,
-        wait_exponential_max=300000,
+        stop_max_attempt_number=10,  # 10 attempts: 1000 max 60000: max wait time is 5 minutes
+        wait_exponential_multiplier=1000,
+        wait_exponential_max=60000,
         retry_on_exception=is_retryable_exception,
     )
-    @log_runtime
     def get_with_retry(
         self,
         aws_service: str,
@@ -307,10 +309,9 @@ class AwsClient:
                 f" is not authorized! Giving up: {e}"
             )
             accumulate("UnauthorizedOperation", "Call to AWS API is not authorized!")
-            raise e  # not allowed to collect in account/region
         elif code in RetryableErrors:
-            log.error(f"Call to {aws_service} action {action} has been retried too many times. Giving up: {e}")
-            accumulate("TooManyRetries", "Call has been retried too often.")
+            log.warning(f"Call to {aws_service} action {action} failed and will be retried eventually. Error: {e}")
+            accumulate("FailedAndRetried", f"Retryable call has failed: {code}.")
             raise e  # already have been retried, give up here
         else:
             log.error(
