@@ -1,4 +1,5 @@
 from resoto_plugin_aws.resource.autoscaling import AwsAutoScalingGroup
+from resotolib.graph import Graph
 from test.resources import round_trip_for
 from typing import cast, Any
 from types import SimpleNamespace
@@ -51,4 +52,4 @@ def test_deletion() -> None:
 
     client = cast(AwsClient, SimpleNamespace(call=validate_args))
 
-    asg.delete_resource(client)
+    asg.delete_resource(client, Graph())
