@@ -1,4 +1,5 @@
 from resoto_plugin_aws.resource.elb import AwsElb
+from resotolib.graph import Graph
 from test.resources import round_trip_for
 from typing import Any, cast
 from types import SimpleNamespace
@@ -18,7 +19,7 @@ def test_elb_deletion() -> None:
         assert kwargs["LoadBalancerName"] == elb.name
 
     client = cast(AwsClient, SimpleNamespace(call=validate_delete_args))
-    elb.delete_resource(client)
+    elb.delete_resource(client, Graph())
 
 
 def test_tagging() -> None:
